==> haskell-conduit-extra-1.3.1.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.1.1
id: conduit-extra-1.3.1.1-KcumXRXf8UFJSbEnt8yrMU
key: conduit-extra-1.3.1.1-KcumXRXf8UFJSbEnt8yrMU
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: 10b35555f584d686d97e8c8b966b6f18
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.6.4/site-local/conduit-extra-1.3.1.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/conduit-extra-1.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/conduit-extra-1.3.1.1
hs-libraries: HSconduit-extra-1.3.1.1-KcumXRXf8UFJSbEnt8yrMU
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-FTcpSH31Ql3KtGJaaDZQpS
    directory-1.3.3.0 filepath-1.4.2.1
    network-2.8.0.0-65TWeU8omLsDYfm0yvOQxG
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    resourcet-1.2.2-5WRYEUs9Kel3m2rSVevxcM stm-2.5.0.0
    streaming-commons-0.2.1.0-LU7KRMKFZnk5zfd2Cwdxoq text-1.2.3.1
    transformers-0.5.6.2 typed-process-0.2.4.0-EBmbj0XKy5VVrWiCME2yR
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.1.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.1.1
id: conduit-extra-1.3.1.1-7ZxQ6ZiVjNd8QNBRTp16o
key: conduit-extra-1.3.1.1-7ZxQ6ZiVjNd8QNBRTp16o
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: 19fe127df3b85e8979c2dc71f28eb602
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.6.4/site-local/conduit-extra-1.3.1.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/conduit-extra-1.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/conduit-extra-1.3.1.1
hs-libraries: HSconduit-extra-1.3.1.1-7ZxQ6ZiVjNd8QNBRTp16o
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-DBoWDvZgddMAQw9hEqn0dn
    directory-1.3.3.0 filepath-1.4.2.1
    network-2.8.0.0-58b93NZ1Nmb3T9F5Ys3Y7W
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    resourcet-1.2.2-1SMNkPIB95cIP5fLPJeWPc stm-2.5.0.0
    streaming-commons-0.2.1.0-H9duiizBozTFZgaMbJuBTO text-1.2.3.1
    transformers-0.5.6.2 typed-process-0.2.4.0-8oa2xCETcuVItTYcsbvZn5
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
